/**
 * Test case for load.
 * Runs with mocha.
 */

'use strict'

const load = require('../lib/load.js')
const assert = require('assert')
const co = require('co')

describe('load', () => {
  it('Render git ignore', () => co(function * () {
    let bud = load({
      type: 'gitignore'
    }, '444', true)
    assert.ok(bud)
    assert.ok(bud.tmpl)
    bud.mkdirp = true
    bud.path = `${__dirname}/../tmp/.gitignore`
    yield require('coz').render(bud)
  }))

  it('Render git ignore with patterns', () => co(function * () {
    let bud = load({
      type: 'gitignore',
      patterns: [
        '# Ignore compiled files.',
        'components/**/*.js',
        '!index.js'
      ]
    }, '444', true)
    assert.ok(bud)
    assert.ok(bud.tmpl)
    bud.mkdirp = true
    bud.path = `${__dirname}/../tmp/sub/.gitignore`
    yield require('coz').render(bud)
  }))

  it('Render npm ignore', () => co(function * () {
    let bud = load({
      type: 'npmignore'
    }, '444', true)
    assert.ok(bud)
    assert.ok(bud.tmpl)
    bud.mkdirp = true
    bud.path = `${__dirname}/../tmp/.npmignore`
    yield require('coz').render(bud)
  }))

  it('Render codecliemate yaml', () => co(function * () {
    let bud = load({
      type: 'codeclimateYml'
    }, '444', true)
    assert.ok(bud)
    assert.ok(bud.tmpl)
    bud.mkdirp = true
    bud.path = `${__dirname}/../tmp/.codecliemate.yml`
    yield require('coz').render(bud)
  }))

  it('Render travis yaml', () => co(function * () {
    let bud = load({
      type: 'travisYml'
    }, '444', true)
    assert.ok(bud)
    assert.ok(bud.tmpl)
    bud.mkdirp = true
    bud.path = `${__dirname}/../tmp/.travis.yml`
    yield require('coz').render(bud)
  }))
})

/* global describe, it */
